#
# Copyright 2009-2011 Martin Owens <doctormo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>
#
"""
Provides some basic methods and classes (which should be replaced)
"""

import os
import dbus
import logging
import gobject
import socket

from MuchMuch import __stage__, __appname__, __testing__

# Load some basic variables
PROJECT_NAME  = "MuchMuch"
PROJECT_PKG   = __appname__
PROJECT_TEST  = __testing__

# The method and signal redefines help readability, imported by other modules
from dbus.mainloop.glib import DBusGMainLoop
from dbus.service import method as dbus_method, signal as dbus_signal, Object

# This MUST happen before the session bus is loaded.
DBusGMainLoop(set_as_default=True)
gobject.threads_init()
dbus.mainloop.glib.threads_init() 

# Dbus Controlling variables
SERVICE_ADDRESS = 'org.anized.Email'
if PROJECT_TEST:
    SERVICE_ADDRESS = 'test.anized.Email'
ROOT_ADDRESS = '/org/anized/Email'
SESSION_BUS = dbus.SessionBus()
SOA = SERVICE_ADDRESS

# =========== Logging ============== #

def set_logging(mode, logfile=None):
    """Set the logging for this session"""
    root = logging.getLogger()
    while len(root.handlers):
        root.removeHandler(root.handlers[0])

    # We will log as debug also if the log file exists.
    if os.path.exists(logfile) or mode == 'file':
        logging.basicConfig(level=logging.DEBUG,
            format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s',
            datefmt='%m-%d %H:%M',
            filename=logfile,
            filemode='w')
    else:
        if __stage__ == 'DEV' or mode == 'stdout':
            logging.basicConfig(level=logging.DEBUG,
                format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s',
                datefmt='%m-%d %H:%M')
        else:
            logging.basicConfig(level=logging.ERROR)

set_logging('stdout', logfile=os.path.expanduser("~/muchmuch.log"))

# =========== Utils ============== #

from fnmatch import fnmatch
def listfiles(*dirs):
    """List files in a directory given a filtership"""
    fdir, pattern = os.path.split(os.path.join(*dirs))
    return [os.path.join(fdir, filename)
        for filename in os.listdir(os.path.abspath(fdir))
            if filename[0] != '.' and fnmatch(filename, pattern)]

def isPortOpen(ip, port):
    """Returns True if the given port is open"""
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    try:
     s.connect((ip, int(port)))
     s.shutdown(2)
     return True
    except:
     return False

# =========== DBus Base ============== #

def dbus_root():
    """Returns the nominal service root object"""
    return dbus_object(ROOT_ADDRESS)

def dbus_object(name):
    """Returns the given dbus object at the standard service address"""
    return SESSION_BUS.get_object(SERVICE_ADDRESS, name)

class DBusObject(Object):
    """Provide a generic backbone to dbus object creation"""
    def __init__(self, address):
        self.address = ROOT_ADDRESS
        if address:
            self.address += '/' + address
        logging.warn("Creating object: %s" % self.address)
        super(DBusObject, self).__init__(SESSION_BUS, self.address)

