#
# Copyright 2011 Martin Owens <doctormo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>
#
"""Configuration (json)"""

import os
import sys
import json
import logging

from MuchMuch import __testing__

XDG_CONF = os.path.expanduser('~/.config')
if __testing__:
    XDG_CONF = os.path.abspath('data')

CONF_FILE = os.path.join(XDG_CONF, 'email.conf')
CONF_DIR  = os.path.join(XDG_CONF, 'email')

# I thought about using inotify to monitor or some other teqnique
# to lock the config file so other processes couldn't write to it.
# But decided against adding that complexity at this time.

class ConfigFile(dict):
    def __init__(self, filename=CONF_FILE):
        self.filename = filename
        self.loaded = False
        try:
            self.update_with( filename )
            self.loaded = True
        except IOError:
            pass

    def update_with(self, filename):
        """Refresh data fromt he hard disk"""
        if os.path.exists(filename):
            with open(filename, 'r') as fhl:
                try:
                    self.update(json.loads(fhl.read()))
                except ValueError:
                    raise ValueError("Invalid Config file: %s" % filename)
        else:
            raise IOError("Load Config: File not found: %s" % filename)

    def save(self, filename=None):
        """Save the data to disk"""
        filename = filename or self.filename
        if filename:
            with open(self.filename, 'w') as fhl:
                fhl.write(json.dumps(self))
        else:
            raise IOError("Save Config: No filename specified.")


