#!/usr/bin/env python
#
# Copyright (C) 2011 Martin Owens <doctormo@gmail.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import sys
sys.path.insert(1, 'lib')
 
from MuchMuch import __appname__, __version__
from distutils.core import setup
from fnmatch import fnmatch

import os, platform

# remove MANIFEST. distutils doesn't properly update it
# when the contents of directories change.
if os.path.exists('MANIFEST'): os.remove('MANIFEST')

if platform.system() == 'FreeBSD':
        man_dir = 'man'
else:
        man_dir = 'share/man'

def listfiles(*dirs):
        dir, pattern = os.path.split(os.path.join(*dirs))
        return [os.path.join(dir, filename)
                for filename in os.listdir(os.path.abspath(dir))
                        if filename[0] != '.' and fnmatch(filename, pattern)]

setup(
        name             = __appname__,
        version          = __version__,
        description      = 'The core of the MuchMuch Email System',
        long_description = "Allows email to be delivered to directories on your system, indexes and provides a dbus interface to access them.",
        author           = 'Martin Owens',
        author_email     = 'doctormo@gmail.com',
        url              = 'https://code.launchpad.net/muchmuch',
        platforms        = 'linux',
        license          = 'GPLv3',
        packages         = [ 'MuchMuch' ],
        scripts          = listfiles( 'bin', '*' ),
        data_files       = [
            ( os.path.join(man_dir, 'man1'),  listfiles( 'doc',     '*.1' ) ),
        ],
        package_dir      = {'': 'lib'},
    )

