#
# Copyright 2011, Martin Owens <doctormo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>
#
"""
Comprise the base class for testing email slots.
"""

import os
import shutil
import time
import dbus

from base_test import Pipette, prepare_data
from base_dbus_test import DBusTestBase, dbus_object
from MuchMuch import client
from MuchMuch.client import MailSlot
from MuchMuch.config import CONF_FILE

class EmailTestBase(DBusTestBase):
    def creation(self):
        self.slot = MailSlot('mailslot0_1424c37c')

    def destruction(self):
        del self.slot

    def search_test(self, search, msgids=None, positive=True):
        """Perform a search and match a message id."""
        search = self.slot.messages(search, out=True)
        if msgids and isinstance(msgids, basestring):
            msgids = [ msgids ]

        if positive:
            self.assertTrue(search, "No Messages Found")
            self.assertIn(msgids, search)
            return search
        else:
            self.assertFalse(search, "Messages Found")

    def delivery_test(self, filename, search):
        msgid = self.slot.deliver(filename, False)
        self.assertFalse(os.path.exists(filename))
        self.search_test(search, msgid)

    def assertIn(self, items, ina):
        """Replace python2.7 method for python2.6"""
        if not items:
            return
        if isinstance(items, basestring):
            items = [items]
        for i in range(len(ina)):
            ina[i] = unicode(ina[i])
        message = "%s not in %s" % (', '.join(items), ', '.join(ina))
        failed = False
        for item in items:
            if item not in ina:
                failed = True
                break
        self.assertFalse(failed, message)

