#
# Copyright (C) 2010 Martin Owens
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Base test classes to poke at the dbus api.
"""

import logging
import atexit

# Tell the system where the modules can be found
import sys
sys.path.insert(1, '../lib')
sys.path.insert(1, 'lib')

# This sets up the dbus api location and logging
import os
os.environ['test_suite'] = 'True'

from unittest import TestCase as TestBox
from test import test_support as Pipette

import shutil

def prepare_data(files, clean=True):
    """Prepare any and all data for this test"""
    for f in files:
        t = f + '.test'
        if not os.path.exists(f):
            if os.path.isfile(t):
                shutil.copyfile(t, f)
            elif os.path.isdir(t):
                shutil.copytree(t, f)
    if clean:
        # Automatically clean data
        atexit.register(clean_data, files)

def clean_data(files):
    """Remove all data for this test"""
    for f in files:
        if os.path.isfile(f):
            os.unlink(f)
        elif os.path.isdir(f):
            shutil.rmtree(f)

