#
# Copyright 2011, Martin Owens <doctormo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>
#
"""
Test scanning directories and finding email and deliverying them.
"""

import os
import shutil
import time
import dbus

from base_test import Pipette, prepare_data
from base_dbus_test import DBusTestBase
from MuchMuch.client import dbus_object
from MuchMuch.config import CONF_FILE, CONF_DIR

class AccountManagerTestCase(DBusTestBase):
    """For testing accounts and the management there in."""
    def test_01_load_account(self):
        """Accounts Loaded"""
        self.assertTrue(self.service_root)
        acts = self.service_root.GetAccounts()
        self.assertEqual(1, len(acts))
        self.assertTrue(acts[0])

    def test_02_mailman_loaded(self):
        """Account Mailman En Route"""
        act = dbus_object(self.service_root.GetAccounts()[0])
        self.assertTrue(act)
        self.assertEqual(act.GetId(), 'test_mail_com')

    def test_03_create_account(self):
        """Create Account"""
        result = self.service_root.CreateAccount('test_type', 'new@mail.com')
        self.assertTrue(result)
        act = dbus_object(self.service_root.GetAccount('new_mail_com'))
        self.assertTrue(act)
        self.assertEqual(act.GetId(), 'new_mail_com')

    def test_04_create_unknown_type(self):
        """Unknown Account Type"""
        self.failUnlessDBusRaises( 'KeyError',
            self.service_root.CreateAccount, 'no_type', 'boo' )

if __name__ == '__main__':
    prepare_data([CONF_DIR, 'data/plugins'], True)
    Pipette.run_unittest( AccountManagerTestCase )

