#
# Copyright 2011, Martin Owens <doctormo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>
#
"""
Test the delivering of emails and removal of emails.
"""

import os
import shutil
import time
import dbus

from base_test import Pipette, prepare_data
from base_slot_test import EmailTestBase
from MuchMuch import client
from MuchMuch.client import MailSlot
from MuchMuch.config import CONF_FILE

class DeliveryTestCase(EmailTestBase):
    """Testcase for creating mailslots via dbus"""
    def test_01_outside(self):
        """Deiver Outisde Message"""
        self.delivery_test('data/outside.eml', 'from:"Outside"')

    def test_02_inside(self):
        """Deliver Inside Message"""
        self.delivery_test('email0.eml', 'from:"Anthony"')

    def test_03_changed_signal(self):
        """Delivery Causes Status Update"""
        filename = 'email1.eml'
        def deliver():
            return self.slot.deliver(filename, False)
        self.signal_setup(self.slot, "NewMessage")
        (msgid, res) = self.signal_test(self.slot, "MessageDelivered", deliver)
        self.assertTrue(msgid, 'Email failed to be delivered')
        self.assertEqual(str(res[0]), msgid)
        # We should NOT have a NewMessage signal
        self.assertFalse(self.signal_wait("NewMessage", 0))

    def test_04_new_message_signal(self):
        """Delivery New Message Signal"""
        filename = 'subdir/email2.eml'
        def deliver():
            return self.slot.deliver(filename, True)
        (msgid, result) = self.signal_test(self.slot, "NewMessage", deliver)
        self.assertTrue(msgid, 'Email failed to send NewMessage')
        self.assertEqual(str(result[0]), msgid)

    def test_05_purge_message(self):
        """Purge Message"""
        filename = 'data/mailslot0/subdir/email3.eml'
        self.assertTrue(os.path.exists(filename))
        msgid = self.slot.deliver(filename, False)

        def delete():
            return self.slot.delete_message(filename, True)

        (success, res) = self.signal_test(self.slot, "MessageDeleted", delete)

        self.assertTrue(success)
        self.assertEqual(msgid, res[0])
        self.assertFalse(os.path.exists(filename))

    def test_06_delete_message(self):
        """Delete Message"""
        filename = 'data/mailslot0/email1.eml'
        self.assertTrue(os.path.exists(filename))
        msgid = self.slot.deliver(filename, False)
        self.slot.delete_message(filename, False)
        self.assertTrue(os.path.exists(filename))


if __name__ == '__main__':
    prepare_data([CONF_FILE, 'data/outside.eml', 'data/mailslot0'], True)
    Pipette.run_unittest( DeliveryTestCase )

