#
# Copyright 2011, Martin Owens <doctormo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>
#
"""
Test scanning directories and finding email and deliverying them.
"""

import os
import shutil
import time
import dbus

from base_test import Pipette, prepare_data
from base_slot_test import EmailTestBase
from MuchMuch import client
from MuchMuch.client import MailSlot
from MuchMuch.config import CONF_FILE

class ScanTestCase(EmailTestBase):
    """For testing the scanning of directories for new messages."""
    def test_01_inside_scan(self):
        """Scan Inside"""
        self.slot.full_scan('data/mailslot0', ['ins'])
        self.search_test("tag:ins", [
            'MESSAGE0@mail.gmail.com', 'MESSAGE1@mail.gmail.com',
            'MESSAGE2@mail.gmail.com', 'MESSAGE3@mail.gmail.com',
        ])

    def test_02_outside_scan(self):
        """Scan Outside"""
        self.assertTrue(os.path.exists('data/outside/email0.eml'))
        self.slot.full_scan('data/outside', ['outs'])
        self.assertFalse(os.path.exists('data/outside/email0.eml'))
        self.search_test("tag:outs", [
            'OUTSIDE0@mail.gmail.com', 'OUTSIDE1@mail.gmail.com',
            'OUTSIDE2@mail.gmail.com', 'OUTSIDE3@mail.gmail.com',
        ])

if __name__ == '__main__':
    prepare_data([CONF_FILE, 'data/outside', 'data/mailslot0'], True)
    Pipette.run_unittest( ScanTestCase )

