#
# Copyright 2011, Martin Owens <doctormo@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>
#
"""
Test write access to a mailslot via dbus
"""

import os
import shutil
import time
import dbus

from base_test import Pipette, prepare_data
from base_slot_test import EmailTestBase
from MuchMuch import client
from MuchMuch.client import MailSlot
from MuchMuch.config import CONF_FILE

class TagTestCase(EmailTestBase):
    """For accessing existing mailslots via dbus"""
    def creation(self):
        EmailTestBase.creation(self)
        self.msgid = self.slot.deliver('email0.eml', False, ['test'])

    def destruction(self):
        try:
            self.slot.delete_message(self.msgid)
        except Exception:
            pass
        EmailTestBase.destruction(self)

    def tag_test(self, tags, msgids=None, positive=True):
        """Method for testing any tag with a search"""
        if not isinstance(tags, list):
            tags = [ tags ]
        for tag in tags:
            # Tags are only 1 letter, this is so STUPID!
            search = 'tag:%s' % str(tag)
            self.search_test(search, msgids, positive)

    def test_01_tag_on_delivery(self):
        """Tag on Delivery"""
        tags = ['dtag1', 'dtag2']
        self.tag_test(tags, (
            self.slot.deliver('subdir/email2.eml', tags=tags),
            self.slot.deliver('subdir/email3.eml', tags=tags)
        ))

    def test_02_add_tag(self):
        """Add Tag to Message"""
        tag = 'testtag1'
        self.tag_test(tag, positive=False)
        success = self.slot.add_tag(self.msgid, tag)
        self.assertTrue(success, "Tag Not Added")
        self.tag_test(tag, self.msgid)

    def test_03_remove_tag(self):
        """Remove Tag from Message"""
        tag = 'testtag1'
        self.tag_test(tag, self.msgid)
        success = self.slot.remove_tag(self.msgid, tag)
        self.assertTrue(success, "Tag Not Deleted")
        self.tag_test(tag, positive=False)

    def test_04_remove_all(self):
        """Remove all Tags from Message"""
        tags = ['tag1', 'tag2', 'tag3']
        for tag in tags:
            self.slot.add_tag(self.msgid, tag)
        self.tag_test(tags, self.msgid)
        success = self.slot.remove_tags(self.msgid)
        self.assertTrue(success, "Tags Not Deleted")
        self.tag_test(tags, positive=False)

    def test_05_delete_tag(self):
        """Delete the tag from all messages."""
        tag = 'testtag6'
        msgs = []
        for c in range(1):
            msgs.append(self.slot.deliver(
                'data/mailslot0/email%d.eml' % c, False, [tag]))
            self.slot.add_tag(msgs[0], tag)
        self.slot.delete_tag(tag)
        self.tag_test(tag, positive=False)


if __name__ == '__main__':
    prepare_data([CONF_FILE, 'data/mailslot0'], True)
    Pipette.run_unittest( TagTestCase )

